summaryrefslogtreecommitdiff
path: root/Source/GetViewModes.S
diff options
context:
space:
mode:
authorChristian A. Weber <chris@gna.ch>1992-05-15 03:21:10 +0000
committerChristian A. Weber <chris@gna.ch>1992-05-15 03:21:10 +0000
commite556b972d1ad64453b3372b486191e2a59c91dda (patch)
tree4eb9264758c36cc75cdcf8daf8dde1517d77cb6a /Source/GetViewModes.S
parent36c824864c02f0a3f62c8a1d365d1670835c8c96 (diff)
downloadiff-library-e556b972d1ad64453b3372b486191e2a59c91dda.tar.gz
iff-library-e556b972d1ad64453b3372b486191e2a59c91dda.tar.bz2
iff-library-e556b972d1ad64453b3372b486191e2a59c91dda.zip
An neue Include-Files angepasst
Diffstat (limited to 'Source/GetViewModes.S')
-rw-r--r--Source/GetViewModes.S36
1 files changed, 20 insertions, 16 deletions
diff --git a/Source/GetViewModes.S b/Source/GetViewModes.S
index e6a10c6..bf5b4b9 100644
--- a/Source/GetViewModes.S
+++ b/Source/GetViewModes.S
@@ -1,13 +1,13 @@
**
-** $Id: $
-** $Revision: $
+** $Id: GetViewModes.S,v 1.1 92/05/12 22:26:49 chris Exp $
+** $Revision: 1.1 $
**
** $Filename: GetViewModes.S $
-** $Author: Christian A. Weber $
+** $Author: chris $
** $Release: 19.1 $
-** $Date: 92/05/11 21:11:27 $
+** $Date: 92/05/12 22:26:49 $
**
-** iff.library/IFFLib_GetViewModes
+** iff.library/IFFL_GetViewModes
**
** COPYRIGHT (C) 1987-1992 BY CHRISTIAN A. WEBER, BRUGGERWEG 2,
** CH-8037 ZUERICH, SWITZERLAND. ALL RIGHTS RESERVED. NO PART
@@ -17,7 +17,7 @@
**
- IDNT IFFLib_GetViewModes
+ IDNT IFFL_GetViewModes
SECTION text,CODE
INCLUDE "IffLib.i"
@@ -27,30 +27,32 @@
XDEF GetViewModesFunc
-******* iff.library/IFFLib_GetViewModes **************************************
+******* iff.library/IFFL_GetViewModes ***************************************
*
* NAME
-* IFFLib_GetViewModes() -- Get Amiga-specific ViewModes
+* IFFL_GetViewModes() -- Get Amiga-specific ViewModes
*
* SYNOPSIS
-* viewmodes = IFFLib_GetViewModes( ifffile )
-* D0 A1
+* viewmodes = IFFL_GetViewModes( iff )
+* D0 A1
*
-* ULONG IFFLib_GetViewModes( IFFFILE )
+* ULONG IFFL_GetViewModes( IFFL_HANDLE )
*
* FUNCTION
* Searches the IFF file for a 'CAMG' chunk which holds the view modes
* information. If there is no CAMG chunk, the view modes are calcu-
* lated using the information in the BitMapHeader structure.
* You can directly put the low WORD of the result of a GetViewModes()
* call into the ns_ViewModes field of a NewScreen structure. All
* forbidden bits are masked out, as suggested by CBM.
*
* INPUTS
-* ifffile - IFF file pointer, returned from OpenIFF()
+* iff - IFF file handle, from OpenIFF()
*
* RESULT
-* viewmodes - LONG containing the view modes (HAM, LACE, HIRES ...)
+* viewmodes - ULONG containing the view modes (HAM, LACE, HIRES ...)
+* All forbidden bits are masked out, as suggested by CBM.
* Under Kickstart V1.3, only the lower WORD is used.
*
* BUGS
@@ -61,6 +63,7 @@
* the correct CAMG chunk.
*
* SEE ALSO
+* <graphics/displayinfo.h>
*
*****************************************************************************
@@ -121,4 +124,5 @@ NotHiRes:
NotInterlace:
rts
+
END
@@ -27,30 +27,32 @@
* information. If there is no CAMG chunk, the view modes are calcu-
* lated using the information in the BitMapHeader structure.
-* You can directly put the low WORD of the result of a GetViewModes()
-* call into the ns_ViewModes field of a NewScreen structure. All
-* forbidden bits are masked out, as suggested by CBM.
+* You can directly put the low WORD of the result of a call to
+* IFFL_ GetViewModes() into the ns_ViewModes field of a NewScreen
+* structure, or you can use the whole ULONG for the SA_DisplayID tag
+* under OS 2.x.
*
* INPUTS